// https://randomnerdtutorials.com/guide-to-1-8-tft-display-with-arduino/
// Web page where wiring details are described for 1.8 TFT and Uno

#include <Adafruit_GFX.h>                                                
#include <Adafruit_ST7735.h>                                             
#include <SPI.h>  
#include <SD.h>                                                                                                                          
#include <Wire.h>
                                                                         
#define TFT_CS     10                                                    
#define TFT_RST    8                                                     
#define TFT_DC     9                                                     
#define TFT_SCLK   13   // set these to be whatever pins you like!
#define TFT_MOSI   11   // set these to be whatever pins you like!                                                                                                                       
                                                                         
Adafruit_ST7735 tft = Adafruit_ST7735(TFT_CS,  TFT_DC, TFT_RST);         

// Volt meter 
// int analogInput = 2;
float Vout = 0.00;
float Vin = 0.00;
float R1 = 100000.0; // resistance of R1 (100K) 
float R2 = 10000.0; // resistance of R2 (10K) 
int val = 0;

// DS3231 RTC
#include "RTClib.h"
RTC_DS3231 rtc;  // RTC structure declaration
// day of the week strings
char daysOfTheWeek[7][12] = {"Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"};
String dates = "";
String times = "";

// SD card library
#include <SPI.h>
#include <SD.h>
File myFile;
String file_name;
                                                                         
void setup(void) 
{ 
  Wire.begin();
  Serial.begin(9600);
  while (!Serial) {
    ; // wait for serial port to connect. Needed for native USB port only
  }

  pinMode(A2, INPUT); //assigning the input port
                                                        
  tft.initR(INITR_BLACKTAB);  // You will need to do this in every sketch
  tft.fillScreen(ST7735_BLACK);                                          

  tft.setRotation(3);                                                                         
  //tft print function!                                                                                          
  tft.setTextSize(2); 

  if(!rtc.begin()) {
    Serial.println("Couldn't find RTC");
    while (1);
  }

  // SD card is pretty straightforward, a single call...
  if (!SD.begin(4)) {
    Serial.println("SD initialization failed!");
    for(;;); // Fatal error, do not continue
  }

  get_time_stamp();
  myFile = SD.open(file_name, FILE_WRITE);                                                                                                                                                            
}                                                                        
                                                                         
void loop() 
{ 
  val = analogRead(A2);//reads the analog input
  Vout = (val * 5.0) / 1024.0; // formula for calculating voltage out i.e. V+, here 5.00
  Vin = Vout / (R2/(R1+R2)); // formula for calculating voltage in i.e. GND
  if (Vin < 0.09)//condition 
  {
     Vin=0.0;//statement to quash undesired reading !
  }                                                              
  tft.setTextColor(ST7735_WHITE);
  tft.setCursor(5,10);                                                  
  tft.print("Voltage is:");                                           
  tft.setTextColor(ST7735_YELLOW);                
  tft.setCursor(30,30);                                                  
  tft.print(Vin); 
  tft.print("V");

  get_time_stamp(); 
  tft.setTextColor(ST7735_WHITE);                
  tft.setCursor(5,60);                                                  
  tft.print("Time now:");  
  tft.setTextColor(ST7735_RED);                
  tft.setCursor(30,80);
  tft.print(times);  

  if (!SD.exists(&file_name[0])) {
    myFile = SD.open(file_name, FILE_WRITE);
  }
  myFile.println(dates+times+","+(String) Vin+"V");
  myFile.close();
  myFile = SD.open(file_name, FILE_WRITE); 
  
  delay(5000); 
  tft.fillScreen(ST7735_BLACK);                                               
} 

String year_data = "";
String month_data = "";
String day_data = "";

void get_time_stamp() {
  DateTime now = rtc.now();   // 현재 날짜, 시간을 모듈에서 가져옵니다.
    
  // Serial.print(now.year(), DEC);  // 년도 표시
  // Serial.print('/');
  // Serial.print(now.month(), DEC); // 월 표시
  // Serial.print('/');
  // Serial.print(now.day(), DEC);   // 일 표시
  year_data = (String) now.year();
  month_data = (String) now.month();
  day_data = (String) now.day();
  dates = year_data+"/"+month_data+"/"+day_data+"-";
  file_name = year_data + month_data + day_data + ".txt";
   
  Serial.print(" (");
  Serial.print(daysOfTheWeek[now.dayOfTheWeek()]);  // 요일 표시
  Serial.print(") ");
 
  Serial.print(now.hour(), DEC);  // 시간 표시
  Serial.print(':');
  Serial.print(now.minute(), DEC);// 분 표시
  Serial.print(':');
  Serial.print(now.second(), DEC);// 초 표시
  Serial.println();  
  times = (String) now.hour()+":"+(String) now.minute()+":"+(String) now.second();
}                     
